-------
Cameras
-------

Bispectral
++++++++++
.. automodule:: crappy.camera.bispectral
   :members:

Meta Camera
+++++++++++
.. automodule:: crappy.camera.camera
   :members:

Camera link
+++++++++++
.. automodule:: crappy.camera.cameralink
   :members:

Fake Camera
+++++++++++
.. automodule:: crappy.camera.fakeCamera
   :members:

JAI
+++
.. automodule:: crappy.camera.jai
   :members:

PiCamera
++++++++
.. automodule:: crappy.camera.picamera_picamera
   :members:

PiCamera - Webcam
+++++++++++++++++
.. automodule:: crappy.camera.picamera_webcam
   :members:

Seek Thermal Pro
++++++++++++++++
.. automodule:: crappy.camera.seek_thermal_pro
   :members:

Streamer
++++++++
.. automodule:: crappy.camera.streamer
   :members:

Webcam
++++++
.. automodule:: crappy.camera.webcam
   :members:

Xi API
++++++
.. automodule:: crappy.camera.xiapi
   :members:

Ximea CV
++++++++
.. automodule:: crappy.camera.ximeaCV
   :members:
